@@ -1,7 +1,7 @@
 import platform
 import sys
 
-OS_NAME = 'WIN' if platform.system() == 'Windows' else 'MAC'
+OS_NAME = 'WIN' if platform.system() == 'Windows' else 'MAC' if platform.system() == 'Darwin' else 'LINUX'
 OS_BIT = platform.architecture()[0]
 EXE = '.exe'
 INI = '.ini'
@@ -25,8 +25,4 @@ EDGEDRIVER_API = 'https://msedgedriver.azureedge.net'
 EDGE = 'edge'
 EDGEDRIVER = f'msedge{DRIVER}'
 EDGEDRIVER_NAME = f'{EDGEDRIVER}{EXE}' if OS_NAME == 'WIN' else EDGEDRIVER
-IEDRIVER_API = 'https://selenium-release.storage.googleapis.com'
-IE = 'ie'
-IEDRIVER = 'IEDriverServer'
-IEDRIVER_NAME = f'{IEDRIVER}{EXE}'
 SAFARI = 'safari'
